@@ -158,42 +158,17 @@ enum {
   SPVM_OPCODE_C_ID_MULNUM_GET_FIELD_LONG,
   SPVM_OPCODE_C_ID_MULNUM_GET_FIELD_FLOAT,
   SPVM_OPCODE_C_ID_MULNUM_GET_FIELD_DOUBLE,
-  SPVM_OPCODE_C_ID_CALL_METHOD_VOID,
-  SPVM_OPCODE_C_ID_CALL_METHOD_BYTE,
-  SPVM_OPCODE_C_ID_CALL_METHOD_SHORT,
-  SPVM_OPCODE_C_ID_CALL_METHOD_INT,
-  SPVM_OPCODE_C_ID_CALL_METHOD_LONG,
-  SPVM_OPCODE_C_ID_CALL_METHOD_FLOAT,
-  SPVM_OPCODE_C_ID_CALL_METHOD_DOUBLE,
-  SPVM_OPCODE_C_ID_CALL_METHOD_OBJECT,
-  SPVM_OPCODE_C_ID_CALL_METHOD_MULNUM_BYTE,
-  SPVM_OPCODE_C_ID_CALL_METHOD_MULNUM_SHORT,
-  SPVM_OPCODE_C_ID_CALL_METHOD_MULNUM_INT,
-  SPVM_OPCODE_C_ID_CALL_METHOD_MULNUM_LONG,
-  SPVM_OPCODE_C_ID_CALL_METHOD_MULNUM_FLOAT,
-  SPVM_OPCODE_C_ID_CALL_METHOD_MULNUM_DOUBLE,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_VOID,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_BYTE,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_SHORT,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_INT,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_LONG,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_FLOAT,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_DOUBLE,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_OBJECT,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_BYTE,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_SHORT,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_INT,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_LONG,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_FLOAT,
-  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_DOUBLE,
+  SPVM_OPCODE_C_ID_CALL_CLASS_METHOD,
+  SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD,
   SPVM_OPCODE_C_ID_ADD_INT,
   SPVM_OPCODE_C_ID_ADD_LONG,
   SPVM_OPCODE_C_ID_ADD_FLOAT,
   SPVM_OPCODE_C_ID_ADD_DOUBLE,
-  SPVM_OPCODE_C_ID_METHODTRACT_INT,
-  SPVM_OPCODE_C_ID_METHODTRACT_LONG,
-  SPVM_OPCODE_C_ID_METHODTRACT_FLOAT,
-  SPVM_OPCODE_C_ID_METHODTRACT_DOUBLE,
+  SPVM_OPCODE_C_ID_SUBTRACT_INT,
+  SPVM_OPCODE_C_ID_SUBTRACT_LONG,
+  SPVM_OPCODE_C_ID_SUBTRACT_FLOAT,
+  SPVM_OPCODE_C_ID_SUBTRACT_DOUBLE,
   SPVM_OPCODE_C_ID_MULTIPLY_INT,
   SPVM_OPCODE_C_ID_MULTIPLY_LONG,
   SPVM_OPCODE_C_ID_MULTIPLY_FLOAT,
