@@ -61,27 +61,27 @@ SPVM_COMPILER* SPVM_COMPILER_new() {
   SPVM_COMPILER_add_basic_types(compiler);
   
   // Add Byte source
-  const char* spvm_byte_module_source = "class Byte {\n  has value : ro byte;\n  sub new : Byte ($value : byte) {\n    my $self = new Byte;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+  const char* spvm_byte_module_source = "class Byte {\n  has value : ro byte;\n  static method new : Byte ($value : byte) {\n    my $self = new Byte;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
   SPVM_HASH_insert(compiler->module_source_symtable, "Byte", strlen("Byte"), (void*)spvm_byte_module_source);
 
   // Add Short source
-  const char* spvm_short_module_source = "class Short {\n  has value : ro short;\n  sub new : Short ($value : short) {\n    my $self = new Short;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+  const char* spvm_short_module_source = "class Short {\n  has value : ro short;\n  static method new : Short ($value : short) {\n    my $self = new Short;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
   SPVM_HASH_insert(compiler->module_source_symtable, "Short", strlen("Short"), (void*)spvm_short_module_source);
 
   // Add Int source
-  const char* spvm_int_module_source = "class Int {\n  has value : ro int;\n  sub new : Int ($value : int) {\n    my $self = new Int;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+  const char* spvm_int_module_source = "class Int {\n  has value : ro int;\n  static method new : Int ($value : int) {\n    my $self = new Int;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
   SPVM_HASH_insert(compiler->module_source_symtable, "Int", strlen("Int"), (void*)spvm_int_module_source);
 
   // Add Long source
-  const char* spvm_long_module_source = "class Long {\n  has value : ro long;\n  sub new : Long ($value : long) {\n    my $self = new Long;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+  const char* spvm_long_module_source = "class Long {\n  has value : ro long;\n  static method new : Long ($value : long) {\n    my $self = new Long;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
   SPVM_HASH_insert(compiler->module_source_symtable, "Long", strlen("Long"), (void*)spvm_long_module_source);
 
   // Add Float source
-  const char* spvm_float_module_source = "class Float {\n  has value : ro float;\n  sub new : Float ($value : float) {\n    my $self = new Float;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+  const char* spvm_float_module_source = "class Float {\n  has value : ro float;\n  static method new : Float ($value : float) {\n    my $self = new Float;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
   SPVM_HASH_insert(compiler->module_source_symtable, "Float", strlen("Float"), (void*)spvm_float_module_source);
 
   // Add Double source
-  const char* spvm_double_module_source = "class Double {\n  has value : ro double;\n  sub new : Double ($value : double) {\n    my $self = new Double;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+  const char* spvm_double_module_source = "class Double {\n  has value : ro double;\n  static method new : Double ($value : double) {\n    my $self = new Double;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
   SPVM_HASH_insert(compiler->module_source_symtable, "Double", strlen("Double"), (void*)spvm_double_module_source);
 
   // use Byte module
@@ -422,9 +422,9 @@ const char* SPVM_COMPILER_create_method_signature(SPVM_COMPILER* compiler, SPVM_
     
     int32_t arg_index;
     for (arg_index = 0; arg_index < method->args->length; arg_index++) {
-      if (method->call_type_id == SPVM_METHOD_C_CALL_TYPE_ID_METHOD && arg_index == 0) {
-        // self
-        length += 4;
+      if (!method->is_class_method && arg_index == 0) {
+        // Nothing
+        continue;
       }
       else {
         SPVM_MY* arg_my_method = SPVM_LIST_fetch(method->args, arg_index);
@@ -453,7 +453,7 @@ const char* SPVM_COMPILER_create_method_signature(SPVM_COMPILER* compiler, SPVM_
   
   char* method_signature = SPVM_COMPILER_ALLOCATOR_safe_malloc_zero(compiler, length + 1);
   
-  // Calcurate sub signature length
+  // Calcurate method signature length
   char* bufptr = method_signature;
   {
     // Return type
@@ -473,9 +473,9 @@ const char* SPVM_COMPILER_create_method_signature(SPVM_COMPILER* compiler, SPVM_
     int32_t arg_index;
     for (arg_index = 0; arg_index < method->args->length; arg_index++) {
       // self
-      if (method->call_type_id == SPVM_METHOD_C_CALL_TYPE_ID_METHOD && arg_index == 0) {
-        memcpy(bufptr, "self", 4);
-        bufptr += 4;
+      if (!method->is_class_method && arg_index == 0) {
+        // Nothing
+        continue;
       }
       else {
         SPVM_MY* arg_my_method = SPVM_LIST_fetch(method->args, arg_index);
